#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of xlart.
# https://github.com/ayvazj/xlart

# Licensed under the MIT license:
# http://www.opensource.org/licenses/MIT-license
# Copyright (c) 2016, James Ayvaz <james.ayvaz@gmail.com>

from xlart.version import __version__  # NOQA
